@@ -25,7 +25,7 @@ dsvdis <- function(x, index, weight = rep(1,ncol(x)), step = 0., diag=FALSE, upp
     attr(tmp2, "Labels") <- dimnames(x)[[1]]
     attr(tmp2, "Diag") <- diag
     attr(tmp2, "Upper") <- upper
-    attr(tmp2, "index") <- choices[i]
+    attr(tmp2, "method") <- choices[i]
     attr(tmp2, "call") <- match.call()
     attr(tmp2, "Size") <- nrow(x)
     return(tmp2)
